<?php

declare(strict_types=1);

namespace Mooore\WordpressIntegration\Controller\Adminhtml\Site;

use Exception;
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\Controller\Result\Json;
use Magento\Framework\Controller\Result\JsonFactory;
use Magento\Framework\Controller\ResultInterface;
use Mooore\WordpressIntegration\Model\Site;

class InlineEdit extends Action
{

    protected $jsonFactory;

    /**
     * @param Context $context
     * @param JsonFactory $jsonFactory
     */
    public function __construct(
        Context $context,
        JsonFactory $jsonFactory
    ) {
        parent::__construct($context);
        $this->jsonFactory = $jsonFactory;
    }

    /**
     * Inline edit action
     *
     * @return ResultInterface
     */
    public function execute()
    {
        /** @var Json $resultJson */
        $resultJson = $this->jsonFactory->create();
        $error = false;
        $messages = [];

        if ($this->getRequest()->getParam('isAjax')) {
            $postItems = $this->getRequest()->getParam('items', []);
            if (!count($postItems)) {
                $messages[] = __('Please correct the data sent.');
                $error = true;
            } else {
                foreach (array_keys($postItems) as $siteId) {
                    /** @var Site $model */
                    $model = $this->_objectManager->create(Site::class)->load($siteId);
                    try {
                        // phpcs:disable
                        $model->setData(array_merge($model->getData(), $postItems[$siteId]));
                        // phpcs:enable
                        $model->save();
                    } catch (Exception $e) {
                        $messages[] = "[Site ID: {$siteId}]  {$e->getMessage()}";
                        $error = true;
                    }
                }
            }
        }

        return $resultJson->setData([
            'messages' => $messages,
            'error' => $error,
        ]);
    }
}
